@@ -61,6 +61,9 @@ class IClient(Generic[Request, Response]):
         """
         raise NotImplementedError
 
+    async def delete(self, **kwargs: Any) -> IResponse[Request, Response]:
+        return await self.request(method='DELETE', **kwargs)
+
     async def get(self, **kwargs: Any) -> IResponse[Request, Response]:
         return await self.request(method='GET', **kwargs)
 
@@ -91,7 +94,8 @@ class IClient(Generic[Request, Response]):
         credential: ICredential | None = None,
         json: list[Any] | dict[str, Any] | None = None,
         params: dict[str, Any] | None = None,
-        headers: dict[str, str] | None = None
+        headers: dict[str, str] | None = None,
+        allow_none: bool = False
     ) -> IResponse[Request, Response]:
         headers: dict[str, str] = headers or {}
         headers.setdefault('User-Agent', self.user_agent)
@@ -113,6 +117,8 @@ class IClient(Generic[Request, Response]):
                 raise
         if response.status_code == 429:
             response = await self.on_rate_limited(response)
+        elif response.status_code == 404 and allow_none:
+            pass
         elif 400 <= response.status_code < 500:
             response = await self.on_client_error(response)
         return response
@@ -135,8 +141,7 @@ class IClient(Generic[Request, Response]):
         self,
         response: IResponse[Any, Any]
     ) -> NoReturn | IResponse[Any, Any]:
-        response.raise_for_status()
-        raise NotImplementedError
+        return response
 
     async def on_rate_limited(
         self,
